{
  pkgs,
  ...
}:

{
  imports = [
    ./common.nix
    ../users/jordan
  ];

  nixpkgs = {
    config.allowUnfree = true;
  };

  services.printing.enable = true;
  services.openssh.startWhenNeeded = true;

  services.pulseaudio.enable = false;
  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    alsa.support32Bit = true;
    pulse.enable = true;
  };

  fileSystems."/mnt/library" = {
    device = "library.mesh.vimium.net:/mnt/library";
    fsType = "nfs";
    options = [
      "nfsvers=4.2"
      "bg"
      "soft"
      "timeo=20"
      "retry=5"
      "nocto"
      "ro"
      "x-systemd.automount"
      "x-systemd.requires=tailscaled.service"
      "noauto"
    ];
  };

  system.autoUpgrade = {
    enable = true;
    flake = "git+ssh://git@git.vimium.com/jordan/nix-config.git";
    randomizedDelaySec = "10min";
  };

  systemd.services.NetworkManager-wait-online.enable = false;

  fonts.packages = with pkgs; [
    corefonts
    noto-fonts
    nerd-fonts.bigblue-terminal
    nerd-fonts.comic-shanns-mono
    nerd-fonts.terminess-ttf
    nerd-fonts.ubuntu-mono
  ];

  modules = {
    system.desktop.gnome.enable = true;
    services.tailscale.enable = true;
  };

  environment.systemPackages = with pkgs; [
    bind
    bmon
    fd
    ffmpeg
    iotop
    # unstable.nix-du
    # unstable.nix-melt
    unstable.nix-tree
    unstable.nix-visualize
    ripgrep
    rsync
    tcpdump
    tokei
    tree
    wl-clipboard
  ];

  environment.sessionVariables.NIXOS_OZONE_WL = "1";
}
